from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

net_minecraft_advancement_AdvancementProgress = TypeVar("net_minecraft_advancement_AdvancementProgress")
AdvancementProgress = net_minecraft_advancement_AdvancementProgress


class AdvancementProgressHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: AdvancementProgress) -> None:
		pass

	@overload
	def isDone(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the advancement is finished, 'false' otherwise. 
		"""
		pass

	@overload
	def isAnyObtained(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if any criteria has already been met, 'false' otherwise. 
		"""
		pass

	@overload
	def getCriteria(self) -> Mapping[str, Long]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all criteria and their completion date. 
		"""
		pass

	@overload
	def getRequirements(self) -> List[List[str]]:
		"""
		Since: 1.8.4 

		Returns:
			all requirements of this advancement. 
		"""
		pass

	@overload
	def getPercentage(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the percentage of finished requirements. 
		"""
		pass

	@overload
	def getFraction(self) -> TextHelper:
		"""
		Since: 1.8.4 

		Returns:
			the fraction of finished requirements to total requirements. 
		"""
		pass

	@overload
	def countObtainedRequirements(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of requirements criteria. 
		"""
		pass

	@overload
	def getUnobtainedCriteria(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			the amount/values of missing criteria. 
		"""
		pass

	@overload
	def getObtainedCriteria(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			the ids of the finished requirements. 
		"""
		pass

	@overload
	def getEarliestProgressObtainDate(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the earliest completion date of all criteria. 
		"""
		pass

	@overload
	def getCriterionProgress(self, criteria: str) -> float:
		"""
		Since: 1.8.4 

		Args:
			criteria: the criteria 

		Returns:
			the completion date of the given criteria or '-1' if the criteria is not met
yet. 
		"""
		pass

	@overload
	def isCriteriaObtained(self, criteria: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			criteria: the criteria 

		Returns:
			'true' if the given criteria is met, 'false' otherwise. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .IItemCooldownManager import IItemCooldownManager
from .IItemCooldownEntry import IItemCooldownEntry

net_minecraft_item_Item = TypeVar("net_minecraft_item_Item")
Item = net_minecraft_item_Item


class MixinItemCooldownManager(IItemCooldownManager):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getCooldownItems(self) -> Mapping[Item, IItemCooldownEntry]:
		pass

	@overload
	def jsmacros_getManagerTicks(self) -> int:
		pass

	pass





from typing import overload
from .Draw3D import Draw3D
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper
from .EntityHelper import EntityHelper
from .Surface import Surface


class Surface_Builder:
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, parent: Draw3D) -> None:
		pass

	@overload
	def pos(self, pos: Pos3D) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos: the position of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, pos: BlockPosHelper) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos: the position of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, x: float, y: float, z: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the surface 
			y: the y position of the surface 
			z: the z position of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getPos(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the position of the surface. 
		"""
		pass

	@overload
	def bindToEntity(self, boundEntity: EntityHelper) -> "Surface_Builder":
		"""The surface will move with the entity at the offset location.\n
		Since: 1.8.4 

		Args:
			boundEntity: the entity to bind the surface to 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getBoundEntity(self) -> EntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			the entity the surface is bound to, or 'null' if it is not bound to an
entity. 
		"""
		pass

	@overload
	def boundOffset(self, entityOffset: Pos3D) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			entityOffset: the offset from the entity's position to render the surface at 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def boundOffset(self, x: float, y: float, z: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x offset from the entity's position to render the surface at 
			y: the y offset from the entity's position to render the surface at 
			z: the z offset from the entity's position to render the surface at 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getBoundOffset(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the offset from the entity's position to render the surface at. 
		"""
		pass

	@overload
	def xRotation(self, xRot: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			xRot: the x rotation of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getXRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the x rotation of the surface. 
		"""
		pass

	@overload
	def yRotation(self, yRot: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			yRot: the y rotation of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getYRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the y rotation of the surface. 
		"""
		pass

	@overload
	def zRotation(self, zRot: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			zRot: the z rotation of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the z rotation of the surface. 
		"""
		pass

	@overload
	def rotation(self, xRot: float, yRot: float, zRot: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			zRot: the z rotation of the surface 
			yRot: the y rotation of the surface 
			xRot: the x rotation of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def rotateCenter(self, rotateCenter: bool) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether to rotate around the center of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this surface should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def rotateToPlayer(self, rotateToPlayer: bool) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotateToPlayer: whether to rotate the surface to face the player or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def doesRotateToPlayer(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the surface should be rotated to face the player, 'false' otherwise. 
		"""
		pass

	@overload
	def width(self, width: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the width of the surface. 
		"""
		pass

	@overload
	def height(self, height: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			height: the height of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getHeight(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the height of the surface. 
		"""
		pass

	@overload
	def size(self, width: float, height: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the surface 
			height: the height of the surface 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def minSubdivisions(self, minSubdivisions: int) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			minSubdivisions: the minimum number of subdivisions 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getMinSubdivisions(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the minimum number of subdivisions. 
		"""
		pass

	@overload
	def renderBack(self, renderBack: bool) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			renderBack: whether the back of the surface should be rendered or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def shouldRenderBack(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the back of the surface should be rendered, 'false' otherwise. 
		"""
		pass

	@overload
	def cull(self, cull: bool) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			cull: whether to enable culling or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isCulled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if culling is enabled for this box, 'false' otherwise. 
		"""
		pass

	@overload
	def zIndex(self, zIndexScale: float) -> "Surface_Builder":
		"""
		Since: 1.8.4 

		Args:
			zIndexScale: the scale of the z-index 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndexScale(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the scale of the z-index. 
		"""
		pass

	@overload
	def buildAndAdd(self) -> Surface:
		"""Creates the surface for the given values and adds it to the draw3D.\n
		Since: 1.8.4 

		Returns:
			the build surface. 
		"""
		pass

	@overload
	def build(self) -> Surface:
		"""Builds the surface from the given values.

		Returns:
			the build surface. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper
from .DyeColorHelper import DyeColorHelper

net_minecraft_entity_passive_SheepEntity = TypeVar("net_minecraft_entity_passive_SheepEntity")
SheepEntity = net_minecraft_entity_passive_SheepEntity


class SheepEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: SheepEntity) -> None:
		pass

	@overload
	def isSheared(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this sheep is sheared, 'false' otherwise. 
		"""
		pass

	@overload
	def isShearable(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this sheep can be sheared, 'false' otherwise. 
		"""
		pass

	@overload
	def getColor(self) -> DyeColorHelper:
		"""
		Since: 1.8.4 

		Returns:
			the color of this sheep. 
		"""
		pass

	@overload
	def isJeb(self) -> bool:
		"""Sheep named 'jeb_' will cycle through all colors when rendered. If sheared, they will
drop their original colored wool.\n
		Since: 1.8.4 

		Returns:
			'true' if the sheep has a rainbow overlay, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from .BaseLibrary import BaseLibrary
from .Vec3D import Vec3D
from .EntityHelper import EntityHelper
from .Vec2D import Vec2D
from .Pos3D import Pos3D
from .Pos2D import Pos2D
from .BlockPosHelper import BlockPosHelper


class FPositionCommon(BaseLibrary):
	"""position helper classes\n
	Since: 1.6.3 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def createVec(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> Vec3D:
		"""create a new vector object\n
		Since: 1.6.3 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def createLookingVector(self, entity: EntityHelper) -> Vec3D:
		"""
		Since: 1.8.4 

		Args:
			entity: 
		"""
		pass

	@overload
	def createLookingVector(self, yaw: float, pitch: float) -> Vec3D:
		"""
		Since: 1.8.4 

		Args:
			pitch: 
			yaw: 
		"""
		pass

	@overload
	def createVec(self, x1: float, y1: float, x2: float, y2: float) -> Vec2D:
		"""
		Since: 1.6.3 

		Args:
			y1: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def createPos(self, x: float, y: float, z: float) -> Pos3D:
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def createPos(self, x: float, y: float) -> Pos2D:
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def createBlockPos(self, x: int, y: int, z: int) -> BlockPosHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the block 
			y: the y position of the block 
			z: the z position of the block 

		Returns:
			a BlockPosHelper for the given coordinates. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseProfile import BaseProfile
from .Core import Core

java_lang_Throwable = TypeVar("java_lang_Throwable")
Throwable = java_lang_Throwable

org_slf4j_Logger = TypeVar("org_slf4j_Logger")
Logger = org_slf4j_Logger


class Profile(BaseProfile):
	ignoredErrors: List[Class]

	@overload
	def __init__(self, runner: Core, logger: Logger) -> None:
		pass

	@overload
	def logError(self, ex: Throwable) -> None:
		pass

	@overload
	def checkJoinedThreadStack(self) -> bool:
		pass

	@overload
	def initRegistries(self) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .FileHandler_FileLineIterator import FileHandler_FileLineIterator

java_io_BufferedInputStream = TypeVar("java_io_BufferedInputStream")
BufferedInputStream = java_io_BufferedInputStream

java_io_File = TypeVar("java_io_File")
File = java_io_File


class FileHandler:
	"""
	Since: 1.1.8 
	"""

	@overload
	def __init__(self, path: str) -> None:
		pass

	@overload
	def __init__(self, path: str, charset: str) -> None:
		pass

	@overload
	def __init__(self, path: File, charset: str) -> None:
		pass

	@overload
	def __init__(self, path: str, charset: Charset) -> None:
		pass

	@overload
	def __init__(self, path: File) -> None:
		pass

	@overload
	def __init__(self, path: File, charset: Charset) -> None:
		pass

	@overload
	def write(self, s: str) -> "FileHandler":
		"""writes a string to the file. this is a destructive operation that replaces the file contents.\n
		Since: 1.1.8 

		Args:
			s: 

		Returns:
			self 
		"""
		pass

	@overload
	def write(self, b: List[float]) -> "FileHandler":
		"""writes a byte array to the file. this is a destructive operation that replaces the file contents.\n
		Since: 1.1.8 

		Args:
			b: 

		Returns:
			self 
		"""
		pass

	@overload
	def read(self) -> str:
		"""
		Since: 1.1.8 
		"""
		pass

	@overload
	def readBytes(self) -> List[float]:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def readLines(self) -> FileHandler_FileLineIterator:
		"""get an iterator for the lines in the file.
please call FileHandler_FileLineIterator#close() when you are done with the iterator to not leak resources.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def streamBytes(self) -> BufferedInputStream:
		"""get an input stream for the file.
please call BufferedInputStream#close() when you are done with the stream to not leak resources.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def append(self, s: str) -> "FileHandler":
		"""
		Since: 1.1.8 

		Args:
			s: 

		Returns:
			self 
		"""
		pass

	@overload
	def append(self, b: List[float]) -> "FileHandler":
		"""
		Since: 1.2.6 

		Args:
			b: 

		Returns:
			self 
		"""
		pass

	@overload
	def getFile(self) -> File:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventHungerChange(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	foodLevel: int

	@overload
	def __init__(self, foodLevel: int) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .EventFilterer import EventFilterer


class EventFilterer_Compound(EventFilterer):

	@overload
	def checkCyclicRef(self, base: "EventFilterer_Compound") -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .FishEntityHelper import FishEntityHelper

net_minecraft_entity_passive_PufferfishEntity = TypeVar("net_minecraft_entity_passive_PufferfishEntity")
PufferfishEntity = net_minecraft_entity_passive_PufferfishEntity


class PufferfishEntityHelper(FishEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PufferfishEntity) -> None:
		pass

	@overload
	def getSize(self) -> int:
		"""A state of 0 means the fish is deflated, a state of 1 means the fish is inflated and a state
of 2 means the fish is fully inflated.\n
		Since: 1.8.4 

		Returns:
			the puff state of this pufferfish. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .Inventory import Inventory

net_minecraft_client_gui_screen_ingame_HandledScreen__ = TypeVar("net_minecraft_client_gui_screen_ingame_HandledScreen__")
HandledScreen = net_minecraft_client_gui_screen_ingame_HandledScreen__


class EventClickSlot(BaseEvent):
	"""event triggered when the user "clicks" a slot in an inventory\n
	Since: 1.6.4 
	"""
	mode: int
	button: int
	slot: int

	@overload
	def __init__(self, screen: HandledScreen, mode: int, button: int, slot: int) -> None:
		pass

	@overload
	def getInventory(self) -> Inventory:
		"""

		Returns:
			inventory associated with the event 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

org_joml_Matrix4f = TypeVar("org_joml_Matrix4f")
Matrix4f = org_joml_Matrix4f

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_client_render_GameRenderer = TypeVar("net_minecraft_client_render_GameRenderer")
GameRenderer = net_minecraft_client_render_GameRenderer

net_minecraft_client_render_Camera = TypeVar("net_minecraft_client_render_Camera")
Camera = net_minecraft_client_render_Camera

net_minecraft_client_render_LightmapTextureManager = TypeVar("net_minecraft_client_render_LightmapTextureManager")
LightmapTextureManager = net_minecraft_client_render_LightmapTextureManager


class MixinWorldRenderer:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def renderInvisibleOutline(self, tickDelta: float, limitTime: float, renderBlockOutline: bool, camera: Camera, gameRenderer: GameRenderer, lightmapTextureManager: LightmapTextureManager, matrix4f: Matrix4f, matrix4f2: Matrix4f, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import List
from .IContainerParent import IContainerParent


class ICategoryTreeParent(IContainerParent):

	@overload
	def selectCategory(self, category: List[str]) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .ItemStackHelper import ItemStackHelper

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack


class EventArmorChange(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	slot: str
	item: ItemStackHelper
	oldItem: ItemStackHelper

	@overload
	def __init__(self, slot: str, item: ItemStack, old: ItemStack) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .IFilter import IFilter

T = TypeVar("T")

class GroupFilter(IFilter, Generic[T]):
	"""
	Since: 1.6.5 
	"""

	@overload
	def add(self, filter: IFilter) -> "GroupFilter":
		pass

	@overload
	def add(self, filters: List[IFilter]) -> "GroupFilter":
		pass

	@overload
	def remove(self, filter: IFilter) -> "GroupFilter":
		pass

	@overload
	def remove(self, filters: List[IFilter]) -> "GroupFilter":
		pass

	@overload
	def getFilters(self) -> List[IFilter]:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping

java_io_InputStream = TypeVar("java_io_InputStream")
InputStream = java_io_InputStream


class HTTPRequest_Response:
	"""
	Since: 1.1.8 
	"""
	headers: Mapping[str, List[str]]
	responseCode: int

	@overload
	def __init__(self, inputStream: InputStream, responseCode: int, headers: Mapping[str, List[str]]) -> None:
		pass

	@overload
	def text(self) -> str:
		"""
		Since: 1.1.8 
		"""
		pass

	@overload
	def json(self) -> object:
		"""Don't use this. Parse HTTPRequest_Response#text() in the guest language\n
		Since: 1.1.8 
		"""
		pass

	@overload
	def byteArray(self) -> List[float]:
		"""
		Since: 1.2.2 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .ServiceScreen import ServiceScreen

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class ServiceListTopbar(MultiElementContainer):

	@overload
	def __init__(self, parent: ServiceScreen, x: int, y: int, width: int, height: int, textRenderer: TextRenderer) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .ItemHelper import ItemHelper
from .ItemStackHelper import ItemStackHelper
from .BlockHelper import BlockHelper
from .BlockStateHelper import BlockStateHelper
from .StatusEffectHelper import StatusEffectHelper
from .EnchantmentHelper import EnchantmentHelper
from .EntityHelper import EntityHelper
from .FluidStateHelper import FluidStateHelper

net_minecraft_entity_EntityType__ = TypeVar("net_minecraft_entity_EntityType__")
EntityType = net_minecraft_entity_EntityType__

net_minecraft_util_Identifier = TypeVar("net_minecraft_util_Identifier")
Identifier = net_minecraft_util_Identifier


class RegistryHelper:
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getItem(self, id: str) -> ItemHelper:
		"""
		Since: 1.8.4 

		Args:
			id: the item's id 

		Returns:
			an ItemHelper for the given item. 
		"""
		pass

	@overload
	def getItemStack(self, id: str) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			id: the item's id 

		Returns:
			an ItemStackHelper for the given item. 
		"""
		pass

	@overload
	def getItemStack(self, id: str, nbt: str) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			nbt: the item's nbt 
			id: the item's id 

		Returns:
			an ItemStackHelper for the given item and nbt data. 
		"""
		pass

	@overload
	def getItemIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all registered item ids. 
		"""
		pass

	@overload
	def getItems(self) -> List[ItemHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all registered items. 
		"""
		pass

	@overload
	def getBlock(self, id: str) -> BlockHelper:
		"""
		Since: 1.8.4 

		Args:
			id: the block's id 

		Returns:
			an BlockHelper for the given block. 
		"""
		pass

	@overload
	def getBlockState(self, id: str) -> BlockStateHelper:
		"""
		Since: 1.8.4 

		Args:
			id: the block's id 

		Returns:
			an BlockStateHelper for the given block. 
		"""
		pass

	@overload
	def getStatusEffect(self, id: str) -> StatusEffectHelper:
		"""

		Args:
			id: the status effect's id 

		Returns:
			an StatusEffectHelper for the given status effect with 0 ticks duration. 
		"""
		pass

	@overload
	def getStatusEffects(self) -> List[StatusEffectHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all registered status effects as StatusEffectHelper s with 0 ticks duration. 
		"""
		pass

	@overload
	def getBlockState(self, id: str, nbt: str) -> BlockStateHelper:
		"""
		Since: 1.8.4 

		Args:
			nbt: the block's nbt 
			id: the block's id 

		Returns:
			an BlockStateHelper for the given block with the specified nbt. 
		"""
		pass

	@overload
	def getBlockIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all registered block ids. 
		"""
		pass

	@overload
	def getBlocks(self) -> List[BlockHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all registered blocks. 
		"""
		pass

	@overload
	def getEnchantment(self, id: str) -> EnchantmentHelper:
		"""
		Since: 1.8.4 

		Args:
			id: the enchantment's id 

		Returns:
			an EnchantmentHelper for the given enchantment. 
		"""
		pass

	@overload
	def getEnchantment(self, id: str, level: int) -> EnchantmentHelper:
		"""
		Since: 1.8.4 

		Args:
			level: the level of the enchantment 
			id: the enchantment's id 

		Returns:
			an EnchantmentHelper for the given enchantment with the specified level. 
		"""
		pass

	@overload
	def getEnchantmentIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all registered enchantment ids. 
		"""
		pass

	@overload
	def getEnchantments(self) -> List[EnchantmentHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all registered enchantments. 
		"""
		pass

	@overload
	def getEntity(self, type: str) -> EntityHelper:
		"""
		Since: 1.8.4 

		Args:
			type: the id of the entity's type 

		Returns:
			an EntityHelper for the given entity. 
		"""
		pass

	@overload
	def getRawEntityType(self, type: str) -> EntityType:
		"""
		Since: 1.8.4 

		Args:
			type: the id of the entity's type 

		Returns:
			an EntityType for the given entity. 
		"""
		pass

	@overload
	def getEntityTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all entity type ids. 
		"""
		pass

	@overload
	def getFluidState(self, id: str) -> FluidStateHelper:
		"""
		Since: 1.8.4 

		Args:
			id: the fluid's id 

		Returns:
			an FluidStateHelper for the given fluid. 
		"""
		pass

	@overload
	def getFeatureIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all feature ids. 
		"""
		pass

	@overload
	def getStructureFeatureIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all structure feature ids. 
		"""
		pass

	@overload
	def getPaintingIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all painting motive ids. 
		"""
		pass

	@overload
	def getParticleTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all particle type ids. 
		"""
		pass

	@overload
	def getGameEventNames(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all game event names. 
		"""
		pass

	@overload
	def getStatusEffectIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all status effect ids. 
		"""
		pass

	@overload
	def getBlockEntityTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all block entity type ids. 
		"""
		pass

	@overload
	def getScreenHandlerIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all screen handler ids. 
		"""
		pass

	@overload
	def getRecipeTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all recipe type ids. 
		"""
		pass

	@overload
	def getVillagerTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all villager type ids. 
		"""
		pass

	@overload
	def getVillagerProfessionIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all villager profession ids. 
		"""
		pass

	@overload
	def getPointOfInterestTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all point of interest type ids. 
		"""
		pass

	@overload
	def getMemoryModuleTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all memory module type ids. 
		"""
		pass

	@overload
	def getSensorTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all villager sensor type ids. 
		"""
		pass

	@overload
	def getActivityTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all villager activity type ids. 
		"""
		pass

	@overload
	def getStatTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all stat type ids. 
		"""
		pass

	@overload
	def getEntityAttributeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all entity attribute ids. 
		"""
		pass

	@overload
	def getPotionTypeIds(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all potion type ids. 
		"""
		pass

	@overload
	def getIdentifier(self, identifier: str) -> Identifier:
		"""
		Since: 1.8.4 

		Args:
			identifier: the String representation of the identifier, with the namespace and path 

		Returns:
			the raw minecraft Identifier. 
		"""
		pass

	@overload
	def parseIdentifier(self, id: str) -> Identifier:
		pass

	@overload
	def parseNameSpace(self, id: str) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_EntityType__ = TypeVar("net_minecraft_entity_EntityType__")
EntityType = net_minecraft_entity_EntityType__

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_world_World = TypeVar("net_minecraft_world_World")
World = net_minecraft_world_World


class MixinLivingEntity(Entity):

	@overload
	def __init__(self, arg: EntityType, arg2: World) -> None:
		pass

	@overload
	def getMaxHealth(self) -> float:
		pass

	@overload
	def onSetHealth(self, health: float, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from .IEventListener import IEventListener
from .ScriptTrigger import ScriptTrigger
from .Core import Core
from .BaseEvent import BaseEvent
from .EventContainer import EventContainer


class BaseListener(IEventListener):
	"""This is for java-sided listeners, for creating listeners script sided directly use IEventListener
	"""

	@overload
	def __init__(self, trigger: ScriptTrigger, runner: Core) -> None:
		pass

	@overload
	def getRawTrigger(self) -> ScriptTrigger:
		pass

	@overload
	def runScript(self, event: BaseEvent) -> EventContainer:
		pass

	@overload
	def joined(self) -> bool:
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def off(self) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .IFilter import IFilter


class StringCompareFilter(IFilter):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, operation: str, compareTo: str) -> None:
		pass

	@overload
	def apply(self, val: str) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_PigEntity = TypeVar("net_minecraft_entity_passive_PigEntity")
PigEntity = net_minecraft_entity_passive_PigEntity


class PigEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PigEntity) -> None:
		pass

	@overload
	def isSaddled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this pig is saddled, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement import RenderElement
from .Alignable import Alignable
from .IDraw2D import IDraw2D

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class Line(RenderElement, Alignable):
	"""
	Since: 1.8.4 
	"""
	parent: IDraw2D
	x1: int
	y1: int
	x2: int
	y2: int
	color: int
	rotation: float
	rotateCenter: bool
	width: float
	zIndex: int

	@overload
	def __init__(self, x1: int, y1: int, x2: int, y2: int, color: int, rotation: float, width: float, zIndex: int) -> None:
		pass

	@overload
	def setX1(self, x1: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			x1: the x position of the start of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX1(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the start of the line. 
		"""
		pass

	@overload
	def setY1(self, y1: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			y1: the y position of the start of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY1(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the start of the line. 
		"""
		pass

	@overload
	def setPos1(self, x1: int, y1: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			y1: the y position of the start of the line 
			x1: the x position of the start of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setX2(self, x2: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			x2: the x position of the end of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX2(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the end of the line. 
		"""
		pass

	@overload
	def setY2(self, y2: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			y2: the y position of the end of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY2(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the end of the line. 
		"""
		pass

	@overload
	def setPos2(self, x2: int, y2: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			y2: the y position of the end of the line 
			x2: the x position of the end of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setPos(self, x1: int, y1: int, x2: int, y2: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			y1: the y position of the start of the line 
			x1: the x position of the start of the line 
			y2: the y position of the end of the line 
			x2: the x position of the end of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setColor(self, color: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line 
			alpha: the alpha of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of the line. 
		"""
		pass

	@overload
	def setAlpha(self, alpha: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			alpha: the alpha value of the line's color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of the line's color. 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			rotation: the rotation (clockwise) of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation (clockwise) of the line. 
		"""
		pass

	@overload
	def setRotateCenter(self, rotateCenter: bool) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether this line should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this line should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def setWidth(self, width: float) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the width of the line. 
		"""
		pass

	@overload
	def setZIndex(self, zIndex: int) -> "Line":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the z-index of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def setParent(self, parent: IDraw2D) -> "Line":
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Line":
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	pass





from typing import overload
from typing import Set


class AutoCompleteSuggester:

	@overload
	def __init__(self, language: str) -> None:
		pass

	@overload
	def getSuggestions(self, start: str) -> Set[str]:
		pass

	pass





from typing import overload
from .Draw3D import Draw3D
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper
from .Box import Box


class Box_Builder:
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, parent: Draw3D) -> None:
		pass

	@overload
	def pos1(self, pos1: Pos3D) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos1(self, pos1: BlockPosHelper) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos1(self, x1: float, y1: float, z1: float) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			z1: the z coordinate of the first position of the box 
			y1: the y coordinate of the first position of the box 
			x1: the x coordinate of the first position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getPos1(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the first position of the box. 
		"""
		pass

	@overload
	def pos2(self, pos2: Pos3D) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos2: the second position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos2(self, pos2: BlockPosHelper) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos2: the second position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos2(self, x2: float, y2: float, z2: float) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			z2: the z coordinate of the second position of the box 
			y2: the y coordinate of the second position of the box 
			x2: the x coordinate of the second position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getPos2(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the second position of the box. 
		"""
		pass

	@overload
	def pos(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			z1: the z coordinate of the first position of the box 
			y1: the y coordinate of the first position of the box 
			z2: the z coordinate of the second position of the box 
			x1: the x coordinate of the first position of the box 
			y2: the y coordinate of the second position of the box 
			x2: the x coordinate of the second position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, pos1: BlockPosHelper, pos2: BlockPosHelper) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the box 
			pos2: the second position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, pos1: Pos3D, pos2: Pos3D) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			pos1: the first position of the box 
			pos2: the second position of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def forBlock(self, x: int, y: int, z: int) -> "Box_Builder":
		"""Highlights the given block position.\n
		Since: 1.8.4 

		Args:
			x: the x coordinate of the block 
			y: the y coordinate of the block 
			z: the z coordinate of the block 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def forBlock(self, pos: BlockPosHelper) -> "Box_Builder":
		"""Highlights the given block position.\n
		Since: 1.8.4 

		Args:
			pos: the block position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, color: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, color: int, alpha: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the fill color of the box 
			alpha: the alpha value for the box's fill color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			r: the red component of the fill color 
			b: the blue component of the fill color 
			g: the green component of the fill color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int, a: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			a: the alpha component of the fill color 
			r: the red component of the fill color 
			b: the blue component of the fill color 
			g: the green component of the fill color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of the box. 
		"""
		pass

	@overload
	def alpha(self, alpha: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			alpha: the alpha value for the box's color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of the box's color. 
		"""
		pass

	@overload
	def fillColor(self, fillColor: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			fillColor: the fill color of the box 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillColor(self, fillColor: int, alpha: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			fillColor: the fill color of the box 
			alpha: the alpha value for the box's fill color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillColor(self, r: int, g: int, b: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			r: the red component of the fill color 
			b: the blue component of the fill color 
			g: the green component of the fill color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillColor(self, r: int, g: int, b: int, a: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			a: the alpha component of the fill color 
			r: the red component of the fill color 
			b: the blue component of the fill color 
			g: the green component of the fill color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getFillColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the fill color of the box. 
		"""
		pass

	@overload
	def fillAlpha(self, fillAlpha: int) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			fillAlpha: the alpha value for the box's fill color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getFillAlpha(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of the box's fill color. 
		"""
		pass

	@overload
	def fill(self, fill: bool) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			fill: 'true' if the box should be filled, 'false' otherwise 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isFilled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the box should be filled, 'false' otherwise. 
		"""
		pass

	@overload
	def cull(self, cull: bool) -> "Box_Builder":
		"""
		Since: 1.8.4 

		Args:
			cull: whether to enable culling or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isCulled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if culling is enabled for this box, 'false' otherwise. 
		"""
		pass

	@overload
	def buildAndAdd(self) -> Box:
		"""Creates the box for the given values and adds it to the draw3D.\n
		Since: 1.8.4 

		Returns:
			the build box. 
		"""
		pass

	@overload
	def build(self) -> Box:
		"""Builds the box from the given values.

		Returns:
			the build box. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity


class IHorseScreen:

	@overload
	def jsmacros_getEntity(self) -> Entity:
		pass

	pass





from typing import overload
from typing import TypeVar
from .DisplayEntityHelper import DisplayEntityHelper
from .BlockStateHelper import BlockStateHelper

net_minecraft_entity_decoration_DisplayEntity_BlockDisplayEntity = TypeVar("net_minecraft_entity_decoration_DisplayEntity_BlockDisplayEntity")
DisplayEntity_BlockDisplayEntity = net_minecraft_entity_decoration_DisplayEntity_BlockDisplayEntity


class BlockDisplayEntityHelper(DisplayEntityHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: DisplayEntity_BlockDisplayEntity) -> None:
		pass

	@overload
	def getBlockState(self) -> BlockStateHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .EntityHelper import EntityHelper
from .ItemStackHelper import ItemStackHelper
from .NBTElementHelper import NBTElementHelper

net_minecraft_predicate_NbtPredicate = TypeVar("net_minecraft_predicate_NbtPredicate")
NbtPredicate = net_minecraft_predicate_NbtPredicate


class NbtPredicateHelper(BaseHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: NbtPredicate) -> None:
		pass

	@overload
	def test(self, entity: EntityHelper) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def test(self, itemStack: ItemStackHelper) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def test(self, nbtElement: NBTElementHelper) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

net_minecraft_entity_effect_StatusEffect = TypeVar("net_minecraft_entity_effect_StatusEffect")
StatusEffect = net_minecraft_entity_effect_StatusEffect

net_minecraft_entity_effect_StatusEffectInstance = TypeVar("net_minecraft_entity_effect_StatusEffectInstance")
StatusEffectInstance = net_minecraft_entity_effect_StatusEffectInstance


class StatusEffectHelper(BaseHelper):
	"""
	Since: 1.2.4 
	"""

	@overload
	def __init__(self, s: StatusEffectInstance) -> None:
		pass

	@overload
	def __init__(self, s: StatusEffect) -> None:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def __init__(self, s: StatusEffect, t: int) -> None:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.2.4 
		"""
		pass

	@overload
	def getStrength(self) -> int:
		"""
		Since: 1.2.4 
		"""
		pass

	@overload
	def getCategory(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the string name of the category of the status effect, "HARMFUL", "NEUTRAL", or "BENEFICIAL". 
		"""
		pass

	@overload
	def getTime(self) -> int:
		"""
		Since: 1.2.4 
		"""
		pass

	@overload
	def isPermanent(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this effect is applied permanently, 'false' otherwise. 
		"""
		pass

	@overload
	def isAmbient(self) -> bool:
		"""Ambient effects are usually applied through beacons and they make the particles more
translucent.\n
		Since: 1.8.4 

		Returns:
			'true' if this effect is an ambient one, 'false' otherwise. 
		"""
		pass

	@overload
	def hasIcon(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this effect has an icon it should render, 'false' otherwise. 
		"""
		pass

	@overload
	def isVisible(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this effect affects the particle color and gets rendered in game, 'false' otherwise. 
		"""
		pass

	@overload
	def isInstant(self) -> bool:
		"""An effect which is instant can still have a duration, but only if it's set through a
command.\n
		Since: 1.8.4 

		Returns:
			'true' if this effect should be applied instantly, 'false' otherwise. 
		"""
		pass

	@overload
	def isBeneficial(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this effect is considered beneficial, 'false' otherwise. 
		"""
		pass

	@overload
	def isNeutral(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this effect is considered neutral, 'false' otherwise. 
		"""
		pass

	@overload
	def isHarmful(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this effect is considered harmful, 'false' otherwise. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .TameableEntityHelper import TameableEntityHelper
from .DyeColorHelper import DyeColorHelper

net_minecraft_entity_passive_WolfEntity = TypeVar("net_minecraft_entity_passive_WolfEntity")
WolfEntity = net_minecraft_entity_passive_WolfEntity


class WolfEntityHelper(TameableEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: WolfEntity) -> None:
		pass

	@overload
	def isBegging(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this wolf is tamed and the player has either a bone or meat in one of
their hands, 'false' otherwise. 
		"""
		pass

	@overload
	def getCollarColor(self) -> DyeColorHelper:
		"""
		Since: 1.8.4 

		Returns:
			the color of this wolf's collar. 
		"""
		pass

	@overload
	def isAngry(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this wolf is angry, 'false' otherwise. 
		"""
		pass

	@overload
	def isWet(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this wolf is wet, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .StatusEffectHelper import StatusEffectHelper

net_minecraft_component_type_FoodComponent = TypeVar("net_minecraft_component_type_FoodComponent")
FoodComponent = net_minecraft_component_type_FoodComponent


class FoodComponentHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: FoodComponent) -> None:
		pass

	@overload
	def getHunger(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of hunger this food restores. 
		"""
		pass

	@overload
	def getSaturation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the amount of saturation this food restores. 
		"""
		pass

	@overload
	def isAlwaysEdible(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this food can be eaten even when the player is not hungry, 'false' otherwise. 
		"""
		pass

	@overload
	def isFastFood(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the food can be eaten faster than usual, 'false' otherwise. 
		"""
		pass

	@overload
	def getStatusEffects(self) -> Mapping[StatusEffectHelper, Float]:
		"""
		Since: 1.8.4 

		Returns:
			a map of status effects and their respective probabilities. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .MobEntityHelper import MobEntityHelper

T = TypeVar("T")

class ZombieEntityHelper(Generic[T], MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def isConvertingToDrowned(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this zombie is converting to a drowned, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper
from .BlockStateHelper import BlockStateHelper

net_minecraft_entity_mob_EndermanEntity = TypeVar("net_minecraft_entity_mob_EndermanEntity")
EndermanEntity = net_minecraft_entity_mob_EndermanEntity


class EndermanEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: EndermanEntity) -> None:
		pass

	@overload
	def isScreaming(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this enderman is screaming, 'false' otherwise. 
		"""
		pass

	@overload
	def isProvoked(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this enderman was provoked by a player, 'false' otherwise. 
		"""
		pass

	@overload
	def isHoldingBlock(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this enderman is holding a block, 'false' otherwise. 
		"""
		pass

	@overload
	def getHeldBlock(self) -> BlockStateHelper:
		"""
		Since: 1.8.4 

		Returns:
			the held block of this enderman, or 'null' if it is not holding a block. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class IScreenInternal:

	@overload
	def jsmacros_render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def jsmacros_mouseClicked(self, mouseX: float, mouseY: float, button: int) -> None:
		pass

	@overload
	def jsmacros_mouseReleased(self, mouseX: float, mouseY: float, button: int) -> None:
		pass

	@overload
	def jsmacros_mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> None:
		pass

	@overload
	def jsmacros_mouseScrolled(self, mouseX: float, mouseY: float, horiz: float, vert: float) -> None:
		pass

	@overload
	def jsmacros_keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> None:
		pass

	@overload
	def jsmacros_charTyped(self, chr: str, modifiers: int) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .IScreen import IScreen
from .IScreenInternal import IScreenInternal
from .Draw2DElement import Draw2DElement
from .Draw2D import Draw2D
from .Line import Line
from .Text import Text
from .Rect import Rect
from .Item import Item
from .Image import Image
from .TextFieldWidgetHelper import TextFieldWidgetHelper
from .ClickableWidgetHelper import ClickableWidgetHelper
from .RenderElement import RenderElement
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .MethodWrapper import MethodWrapper
from .CheckBoxWidgetHelper import CheckBoxWidgetHelper
from .SliderWidgetHelper import SliderWidgetHelper
from .LockButtonWidgetHelper import LockButtonWidgetHelper
from .CyclingButtonWidgetHelper import CyclingButtonWidgetHelper
from .ButtonWidgetHelper_ButtonBuilder import ButtonWidgetHelper_ButtonBuilder
from .CheckBoxWidgetHelper_CheckBoxBuilder import CheckBoxWidgetHelper_CheckBoxBuilder
from .CyclingButtonWidgetHelper_CyclicButtonBuilder import CyclingButtonWidgetHelper_CyclicButtonBuilder
from .LockButtonWidgetHelper_LockButtonBuilder import LockButtonWidgetHelper_LockButtonBuilder
from .SliderWidgetHelper_SliderBuilder import SliderWidgetHelper_SliderBuilder
from .TextFieldWidgetHelper_TextFieldBuilder import TextFieldWidgetHelper_TextFieldBuilder
from .ButtonWidgetHelper_TexturedButtonBuilder import ButtonWidgetHelper_TexturedButtonBuilder

net_minecraft_client_gui_AbstractParentElement = TypeVar("net_minecraft_client_gui_AbstractParentElement")
AbstractParentElement = net_minecraft_client_gui_AbstractParentElement

T = TypeVar("T")
org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_ = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_")
CallbackInfoReturnable = org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Style = TypeVar("net_minecraft_text_Style")
Style = net_minecraft_text_Style

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class MixinScreen(IScreen, IScreenInternal, AbstractParentElement):
	width: int
	height: int
	textRenderer: TextRenderer

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onClose(self) -> None:
		pass

	@overload
	def tick(self) -> None:
		pass

	@overload
	def handleTextClick(self, style: Style) -> bool:
		pass

	@overload
	def getWidth(self) -> int:
		pass

	@overload
	def getHeight(self) -> int:
		pass

	@overload
	def getDraw2Ds(self) -> List[Draw2DElement]:
		pass

	@overload
	def addDraw2D(self, draw2D: Draw2D, x: int, y: int, width: int, height: int) -> Draw2DElement:
		pass

	@overload
	def addDraw2D(self, draw2D: Draw2D, x: int, y: int, width: int, height: int, zIndex: int) -> Draw2DElement:
		pass

	@overload
	def removeDraw2D(self, draw2D: Draw2DElement) -> IScreen:
		pass

	@overload
	def getLines(self) -> List[Line]:
		pass

	@overload
	def getTexts(self) -> List[Text]:
		pass

	@overload
	def getRects(self) -> List[Rect]:
		pass

	@overload
	def getItems(self) -> List[Item]:
		pass

	@overload
	def getImages(self) -> List[Image]:
		pass

	@overload
	def getTextFields(self) -> List[TextFieldWidgetHelper]:
		pass

	@overload
	def getButtonWidgets(self) -> List[ClickableWidgetHelper]:
		pass

	@overload
	def getElements(self) -> List[RenderElement]:
		pass

	@overload
	def removeElement(self, e: RenderElement) -> IScreen:
		pass

	@overload
	def reAddElement(self, e: T) -> T:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool) -> Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool) -> Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> Text:
		pass

	@overload
	def removeText(self, t: Text) -> IScreen:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.4.0 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def removeImage(self, i: Image) -> IScreen:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int) -> Rect:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int) -> Rect:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float) -> Rect:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float, zIndex: int) -> Rect:
		pass

	@overload
	def removeRect(self, r: Rect) -> IScreen:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, width: float) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int, width: float) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, width: float, rotation: float) -> Line:
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int, width: float, rotation: float) -> Line:
		pass

	@overload
	def removeLine(self, l: Line) -> IScreen:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool, scale: float, rotation: float) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> Item:
		pass

	@overload
	def removeItem(self, i: Item) -> IScreen:
		pass

	@overload
	def getScreenClassName(self) -> str:
		pass

	@overload
	def getTitleText(self) -> str:
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, text: str, callback: MethodWrapper) -> ClickableWidgetHelper:
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, callback: MethodWrapper) -> ClickableWidgetHelper:
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, text: str, checked: bool, showMessage: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, text: str, checked: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, checked: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, checked: bool, showMessage: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, text: str, value: float, steps: int, callback: MethodWrapper) -> SliderWidgetHelper:
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, value: float, callback: MethodWrapper) -> SliderWidgetHelper:
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, text: str, value: float, callback: MethodWrapper) -> SliderWidgetHelper:
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, value: float, steps: int, callback: MethodWrapper) -> SliderWidgetHelper:
		pass

	@overload
	def addLockButton(self, x: int, y: int, callback: MethodWrapper) -> LockButtonWidgetHelper:
		pass

	@overload
	def addLockButton(self, x: int, y: int, zIndex: int, callback: MethodWrapper) -> LockButtonWidgetHelper:
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, values: List[str], initial: str, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, zIndex: int, values: List[str], initial: str, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, zIndex: int, values: List[str], alternatives: List[str], initial: str, prefix: str, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, zIndex: int, values: List[str], alternatives: List[str], initial: str, prefix: str, alternateToggle: MethodWrapper, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		pass

	@overload
	def removeButton(self, btn: ClickableWidgetHelper) -> IScreen:
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, zIndex: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		pass

	@overload
	def removeTextInput(self, inp: TextFieldWidgetHelper) -> IScreen:
		pass

	@overload
	def soft$close(self) -> None:
		pass

	@overload
	def setOnMouseDown(self, onMouseDown: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnMouseDrag(self, onMouseDrag: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnMouseUp(self, onMouseUp: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnScroll(self, onScroll: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnKeyPressed(self, onKeyPressed: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnCharTyped(self, onCharTyped: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnInit(self, onInit: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnFailInit(self, catchInit: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnClose(self, onClose: MethodWrapper) -> IScreen:
		pass

	@overload
	def reloadScreen(self) -> IScreen:
		pass

	@overload
	def buttonBuilder(self) -> ButtonWidgetHelper_ButtonBuilder:
		pass

	@overload
	def checkBoxBuilder(self) -> CheckBoxWidgetHelper_CheckBoxBuilder:
		pass

	@overload
	def checkBoxBuilder(self, checked: bool) -> CheckBoxWidgetHelper_CheckBoxBuilder:
		pass

	@overload
	def cyclicButtonBuilder(self, valueToText: MethodWrapper) -> CyclingButtonWidgetHelper_CyclicButtonBuilder:
		pass

	@overload
	def lockButtonBuilder(self) -> LockButtonWidgetHelper_LockButtonBuilder:
		pass

	@overload
	def lockButtonBuilder(self, locked: bool) -> LockButtonWidgetHelper_LockButtonBuilder:
		pass

	@overload
	def sliderBuilder(self) -> SliderWidgetHelper_SliderBuilder:
		pass

	@overload
	def textFieldBuilder(self) -> TextFieldWidgetHelper_TextFieldBuilder:
		pass

	@overload
	def texturedButtonBuilder(self) -> ButtonWidgetHelper_TexturedButtonBuilder:
		pass

	@overload
	def jsmacros_render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def jsmacros_mouseClicked(self, mouseX: float, mouseY: float, button: int) -> None:
		pass

	@overload
	def jsmacros_mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> None:
		pass

	@overload
	def jsmacros_mouseReleased(self, mouseX: float, mouseY: float, button: int) -> None:
		pass

	@overload
	def jsmacros_keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> None:
		pass

	@overload
	def jsmacros_charTyped(self, chr: str, modifiers: int) -> None:
		pass

	@overload
	def jsmacros_mouseScrolled(self, mouseX: float, mouseY: float, horiz: float, vert: float) -> None:
		pass

	@overload
	def handleCustomClickEvent(self, style: Style, cir: CallbackInfoReturnable) -> None:
		pass

	@overload
	def getOnClose(self) -> MethodWrapper:
		pass

	pass





from typing import overload
from .IMerchantScreen import IMerchantScreen


class MixinMerchantScreen(IMerchantScreen):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_selectIndex(self, index: int) -> None:
		pass

	pass





from typing import overload
from .EventFilterer_Compound import EventFilterer_Compound
from .EventFilterer import EventFilterer
from .BaseEvent import BaseEvent


class FiltererComposed(EventFilterer_Compound):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, initial: EventFilterer) -> None:
		pass

	@overload
	def canFilter(self, event: str) -> bool:
		pass

	@overload
	def test(self, event: BaseEvent) -> bool:
		pass

	@overload
	def and_(self, filterer: EventFilterer) -> "FiltererComposed":
		"""

		Args:
			filterer: the filterer to compose 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def or_(self, filterer: EventFilterer) -> "FiltererComposed":
		"""

		Args:
			filterer: the filterer to compose 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def checkCyclicRef(self, base: EventFilterer_Compound) -> None:
		pass

	pass





from typing import overload
from typing import Mapping
from .Mappings_MethodData import Mappings_MethodData


class Mappings_ClassData:
	methods: Mapping[str, Mappings_MethodData]
	fields: Mapping[str, str]
	name: str

	@overload
	def __init__(self, name: str) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import Any
from .ModContainerHelper import ModContainerHelper


class ModLoader:
	"""
	Since: 1.8.4 
	"""

	@overload
	def isDevEnv(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the game is running in a development environment, 'false' otherwise. 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of the current mod loader. 
		"""
		pass

	@overload
	def getLoadedMods(self) -> List[Any]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all loaded mods. 
		"""
		pass

	@overload
	def isModLoaded(self, modId: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			modId: the mod id to check 

		Returns:
			'true' if the mod with the given id is loaded, 'false' otherwise. 
		"""
		pass

	@overload
	def getMod(self, modId: str) -> ModContainerHelper:
		"""
		Since: 1.8.4 

		Args:
			modId: the mod id 

		Returns:
			the mod container for the given id or 'null' if the mod is not loaded. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_PolarBearEntity = TypeVar("net_minecraft_entity_passive_PolarBearEntity")
PolarBearEntity = net_minecraft_entity_passive_PolarBearEntity


class PolarBearEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PolarBearEntity) -> None:
		pass

	@overload
	def isAttacking(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the polar bear is standing up to attack, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .BlockHelper import BlockHelper
from .BlockStateHelper import BlockStateHelper
from .FoodComponentHelper import FoodComponentHelper

net_minecraft_item_Item = TypeVar("net_minecraft_item_Item")
Item = net_minecraft_item_Item


class ItemHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: Item) -> None:
		pass

	@overload
	def getCreativeTab(self) -> List[TextHelper]:
		"""
		Since: 1.8.4 

		Returns:
			the name of this item's group or '"UNKNOWN"' if this item is not in a group. 
		"""
		pass

	@overload
	def getGroupIcon(self) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Returns:
			the item stack representing the group of this item or 'null' if this item is
not in a group. 
		"""
		pass

	@overload
	def canBeRepairedWith(self, stack: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			stack: the possible repair material 

		Returns:
			'true' if the given item stack can be used to repair item stacks of this item, 'false' otherwise. 
		"""
		pass

	@overload
	def isSuitableFor(self, block: BlockHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			block: the block to check 

		Returns:
			'true' if the given block can be mined and drops when broken with this item, 'false' otherwise. 
		"""
		pass

	@overload
	def isSuitableFor(self, block: BlockStateHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			block: the block to check 

		Returns:
			'true' if the given block can be mined and drops when broken with this item, 'false' otherwise. 
		"""
		pass

	@overload
	def isBlockItem(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the item has a block representation, 'false' otherwise. 
		"""
		pass

	@overload
	def getBlock(self) -> BlockHelper:
		"""
		Since: 1.8.4 

		Returns:
			the block representation of this item or 'null' if this item has no
corresponding block. 
		"""
		pass

	@overload
	def getMiningSpeedMultiplier(self, state: BlockStateHelper) -> float:
		"""
		Since: 1.8.4 

		Args:
			state: the block state to check 

		Returns:
			the mining speed of this item against the given block state, returns '1' by
default. 
		"""
		pass

	@overload
	def isDamageable(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the item has durability, 'false' otherwise. 
		"""
		pass

	@overload
	def hasRecipeRemainder(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if when crafter the item stack has a remainder, 'false' otherwise. 
		"""
		pass

	@overload
	def getRecipeRemainder(self) -> "ItemHelper":
		"""
		Since: 1.8.4 

		Returns:
			the recipe remainder if it exists and 'null' otherwise. 
		"""
		pass

	@overload
	def getEnchantability(self) -> int:
		"""With increased enchantability the change to get more and better enchantments increases.\n
		Since: 1.8.4 

		Returns:
			the enchantability of this item, returns '0' by default. 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this item, translated to the current language. 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the identifier of this item. 
		"""
		pass

	@overload
	def getMaxCount(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum amount of items in a stack of this item. 
		"""
		pass

	@overload
	def getMaxDurability(self) -> int:
		"""The damage an item has taken is the opposite of the durability still left.\n
		Since: 1.8.4 

		Returns:
			the maximum amount of damage this item can take. 
		"""
		pass

	@overload
	def isFireproof(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item is fireproof, 'false' otherwise. 
		"""
		pass

	@overload
	def isTool(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item is a tool, 'false' otherwise. 
		"""
		pass

	@overload
	def isWearable(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item can be worn in the armor slot, 'false' otherwise. 
		"""
		pass

	@overload
	def isFood(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item is food, 'false' otherwise. 
		"""
		pass

	@overload
	def getFood(self) -> FoodComponentHelper:
		"""
		Since: 1.8.4 

		Returns:
			the food component of this item or 'null' if this item is not food. 
		"""
		pass

	@overload
	def canBeNested(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item can be nested, i.e. put into a bundle or shulker box, 'false' otherwise. 
		"""
		pass

	@overload
	def getDefaultStack(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the default item stack of this item with a stack size of '1' . 
		"""
		pass

	@overload
	def getStackWithNbt(self, nbt: str) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			nbt: the nbt data of the item stack 

		Returns:
			the item stack of this item with a stack size of '1' and the given nbt. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .TameableEntityHelper import TameableEntityHelper
from .DyeColorHelper import DyeColorHelper

net_minecraft_entity_passive_CatEntity = TypeVar("net_minecraft_entity_passive_CatEntity")
CatEntity = net_minecraft_entity_passive_CatEntity


class CatEntityHelper(TameableEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: CatEntity) -> None:
		pass

	@overload
	def isSleeping(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this cat is sleeping, 'false' otherwise. 
		"""
		pass

	@overload
	def getCollarColor(self) -> DyeColorHelper:
		"""
		Since: 1.8.4 

		Returns:
			the color of this cat's collar. 
		"""
		pass

	@overload
	def getVariant(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the variant of this cat. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .EntityHelper import EntityHelper

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity

net_minecraft_entity_Entity_RemovalReason = TypeVar("net_minecraft_entity_Entity_RemovalReason")
Entity_RemovalReason = net_minecraft_entity_Entity_RemovalReason


class EventEntityUnload(BaseEvent):
	entity: EntityHelper
	reason: str

	@overload
	def __init__(self, e: Entity, reason: Entity_RemovalReason) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .BlockPosHelper import BlockPosHelper

com_mojang_brigadier_suggestion_SuggestionsBuilder = TypeVar("com_mojang_brigadier_suggestion_SuggestionsBuilder")
SuggestionsBuilder = com_mojang_brigadier_suggestion_SuggestionsBuilder


class SuggestionsBuilderHelper(BaseHelper):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, base: SuggestionsBuilder) -> None:
		pass

	@overload
	def getInput(self) -> str:
		pass

	@overload
	def getStart(self) -> int:
		pass

	@overload
	def getRemaining(self) -> str:
		pass

	@overload
	def getRemainingLowerCase(self) -> str:
		pass

	@overload
	def suggest(self, suggestion: str) -> "SuggestionsBuilderHelper":
		pass

	@overload
	def suggest(self, value: int) -> "SuggestionsBuilderHelper":
		pass

	@overload
	def suggestWithTooltip(self, suggestion: str, tooltip: TextHelper) -> "SuggestionsBuilderHelper":
		pass

	@overload
	def suggestWithTooltip(self, value: int, tooltip: TextHelper) -> "SuggestionsBuilderHelper":
		pass

	@overload
	def suggestMatching(self, suggestions: List[str]) -> "SuggestionsBuilderHelper":
		"""
		Since: 1.8.4 

		Args:
			suggestions: the strings to match 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestMatching(self, suggestions: List[str]) -> "SuggestionsBuilderHelper":
		"""
		Since: 1.8.4 

		Args:
			suggestions: the strings to match 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestIdentifier(self, identifiers: List[str]) -> "SuggestionsBuilderHelper":
		"""
		Since: 1.8.4 

		Args:
			identifiers: the identifiers to match 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestIdentifier(self, identifiers: List[str]) -> "SuggestionsBuilderHelper":
		"""
		Since: 1.8.4 

		Args:
			identifiers: the identifiers to match 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestBlockPositions(self, positions: List[BlockPosHelper]) -> "SuggestionsBuilderHelper":
		"""
		Since: 1.8.4 

		Args:
			positions: the positions to suggest 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestBlockPositions(self, positions: List[BlockPosHelper]) -> "SuggestionsBuilderHelper":
		"""
		Since: 1.8.4 

		Args:
			positions: the positions to suggest 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestPositions(self, positions: List[str]) -> "SuggestionsBuilderHelper":
		"""Positions are strings of the form "x y z" where x, y, and z are numbers or the default
minecraft selectors "~" and "^" followed by a number.\n
		Since: 1.8.4 

		Args:
			positions: the positions to suggest 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def suggestPositions(self, positions: List[str]) -> "SuggestionsBuilderHelper":
		"""Positions are strings of the form "x y z" where x, y, and z are numbers or the default
minecraft selectors "~" and "^" followed by a number.\n
		Since: 1.8.4 

		Args:
			positions: the relative positions to suggest 

		Returns:
			self for chaining. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_function_Function_T,net_minecraft_text_Text_ = TypeVar("java_util_function_Function_T,net_minecraft_text_Text_")
Function = java_util_function_Function_T,net_minecraft_text_Text_

T = TypeVar("T")
net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class MixinCyclingButton:
	"""
	Since: 1.8.4 
	"""

	@overload
	def invokeCycle(self, amount: int) -> None:
		pass

	@overload
	def invokeComposeText(self, value: T) -> Text:
		pass

	@overload
	def getValueToText(self) -> Function:
		pass

	pass





from typing import overload
from typing import List
from .ICompare import ICompare


class StringCompareFilter_FilterMethod:
	CONTAINS: "StringCompareFilter_FilterMethod"
	EQUALS: "StringCompareFilter_FilterMethod"
	STARTS_WITH: "StringCompareFilter_FilterMethod"
	ENDS_WITH: "StringCompareFilter_FilterMethod"
	MATCHES: "StringCompareFilter_FilterMethod"

	@overload
	def values(self) -> List["StringCompareFilter_FilterMethod"]:
		pass

	@overload
	def valueOf(self, name: str) -> "StringCompareFilter_FilterMethod":
		pass

	@overload
	def getMethod(self) -> ICompare:
		pass

	pass





from typing import overload


class IPackedIntegerArray:

	@overload
	def jsmacros_getMaxValue(self) -> float:
		pass

	@overload
	def jsmacros_getElementsPerLong(self) -> int:
		pass

	@overload
	def jsmacros_getIndexScale(self) -> int:
		pass

	@overload
	def jsmacros_getIndexOffset(self) -> int:
		pass

	@overload
	def jsmacros_getIndexShift(self) -> int:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .LivingEntityHelper import LivingEntityHelper
from .TradeOfferHelper import TradeOfferHelper

T = TypeVar("T")

class MerchantEntityHelper(Generic[T], LivingEntityHelper):

	@overload
	def __init__(self, e: T) -> None:
		pass

	@overload
	def getTrades(self) -> List[TradeOfferHelper]:
		"""these might not work... depends on the data the server sends, maybe just singleplayer.
		"""
		pass

	@overload
	def refreshTrades(self) -> List[TradeOfferHelper]:
		pass

	@overload
	def getExperience(self) -> int:
		"""
		"""
		pass

	@overload
	def hasCustomer(self) -> bool:
		"""
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .Pos2D import Pos2D
from .Vec3D import Vec3D
from .BlockPosHelper import BlockPosHelper

net_minecraft_util_math_BlockPos = TypeVar("net_minecraft_util_math_BlockPos")
BlockPos = net_minecraft_util_math_BlockPos

net_minecraft_util_math_Vec3d = TypeVar("net_minecraft_util_math_Vec3d")
Vec3d = net_minecraft_util_math_Vec3d


class Pos3D(Pos2D):
	"""
	Since: 1.2.6 [citation needed] 
	"""
	ZERO: "Pos3D"
	z: float

	@overload
	def __init__(self, vec: Vec3d) -> None:
		pass

	@overload
	def __init__(self, x: float, y: float, z: float) -> None:
		pass

	@overload
	def getZ(self) -> float:
		pass

	@overload
	def add(self, pos: "Pos3D") -> "Pos3D":
		pass

	@overload
	def add(self, x: float, y: float, z: float) -> "Pos3D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def sub(self, pos: "Pos3D") -> "Pos3D":
		"""
		Since: 1.8.4 

		Args:
			pos: the position to subtract 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def sub(self, x: float, y: float, z: float) -> "Pos3D":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to subtract 
			y: the y coordinate to subtract 
			z: the z coordinate to subtract 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def multiply(self, pos: "Pos3D") -> "Pos3D":
		pass

	@overload
	def multiply(self, x: float, y: float, z: float) -> "Pos3D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def divide(self, pos: "Pos3D") -> "Pos3D":
		"""
		Since: 1.8.4 

		Args:
			pos: the position to divide by 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def divide(self, x: float, y: float, z: float) -> "Pos3D":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to divide by 
			y: the y coordinate to divide by 
			z: the z coordinate to divide by 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "Pos3D":
		"""
		Since: 1.6.3 

		Args:
			scale: 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def toVector(self) -> Vec3D:
		pass

	@overload
	def toVector(self, start_pos: Pos2D) -> Vec3D:
		"""
		Since: 1.6.4 

		Args:
			start_pos: 
		"""
		pass

	@overload
	def toVector(self, start_pos: "Pos3D") -> Vec3D:
		"""
		Since: 1.6.4 

		Args:
			start_pos: 
		"""
		pass

	@overload
	def toVector(self, start_x: float, start_y: float, start_z: float) -> Vec3D:
		"""
		Since: 1.6.4 

		Args:
			start_x: 
			start_z: 
			start_y: 
		"""
		pass

	@overload
	def toReverseVector(self) -> Vec3D:
		"""
		Since: 1.6.4 
		"""
		pass

	@overload
	def toReverseVector(self, end_pos: Pos2D) -> Vec3D:
		pass

	@overload
	def toReverseVector(self, end_pos: "Pos3D") -> Vec3D:
		"""
		Since: 1.6.4 

		Args:
			end_pos: 
		"""
		pass

	@overload
	def toReverseVector(self, end_x: float, end_y: float, end_z: float) -> Vec3D:
		"""
		Since: 1.6.4 

		Args:
			end_z: 
			end_x: 
			end_y: 
		"""
		pass

	@overload
	def toBlockPos(self) -> BlockPosHelper:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def toRawBlockPos(self) -> BlockPos:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def toMojangDoubleVector(self) -> Vec3d:
		"""
		Since: 1.8.4 

		Returns:
			the raw minecraft double vector with the same coordinates as this position. 
		"""
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareTo(self, o: "Pos3D") -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .NBTElementHelper_NBTCompoundHelper import NBTElementHelper_NBTCompoundHelper
from .BlockStateHelper import BlockStateHelper
from .BlockHelper import BlockHelper
from .BlockPosHelper import BlockPosHelper

net_minecraft_block_BlockState = TypeVar("net_minecraft_block_BlockState")
BlockState = net_minecraft_block_BlockState

net_minecraft_block_Block = TypeVar("net_minecraft_block_Block")
Block = net_minecraft_block_Block

net_minecraft_util_math_BlockPos = TypeVar("net_minecraft_util_math_BlockPos")
BlockPos = net_minecraft_util_math_BlockPos

net_minecraft_block_entity_BlockEntity = TypeVar("net_minecraft_block_entity_BlockEntity")
BlockEntity = net_minecraft_block_entity_BlockEntity


class BlockDataHelper(BaseHelper):
	"""
	"""

	@overload
	def __init__(self, b: BlockState, e: BlockEntity, bp: BlockPos) -> None:
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			the 'x' value of the block. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			the 'y' value of the block. 
		"""
		pass

	@overload
	def getZ(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			the 'z' value of the block. 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""

		Returns:
			the item ID of the block. 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""

		Returns:
			the translated name of the block. (was string before 1.6.5) 
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper_NBTCompoundHelper:
		"""
		Since: 1.5.1, used to be a Map String , String 
		"""
		pass

	@overload
	def getBlockStateHelper(self) -> BlockStateHelper:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getBlockHelper(self) -> BlockHelper:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getBlock(self) -> BlockHelper:
		"""
		Since: 1.6.5 

		Returns:
			the block 
		"""
		pass

	@overload
	def getBlockState(self) -> Mapping[str, str]:
		"""
		Since: 1.1.7 

		Returns:
			block state data as a Map . 
		"""
		pass

	@overload
	def getBlockPos(self) -> BlockPosHelper:
		"""
		Since: 1.2.7 

		Returns:
			the block pos. 
		"""
		pass

	@overload
	def getRawBlock(self) -> Block:
		pass

	@overload
	def getRawBlockState(self) -> BlockState:
		pass

	@overload
	def getRawBlockEntity(self) -> BlockEntity:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from .OptionType import OptionType


class Option:

	@overload
	def translationKey(self) -> str:
		pass

	@overload
	def group(self) -> List[str]:
		pass

	@overload
	def setter(self) -> str:
		pass

	@overload
	def getter(self) -> str:
		pass

	@overload
	def options(self) -> str:
		pass

	@overload
	def type(self) -> OptionType:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .Extension import Extension
from .Core import Core
from .ScriptTrigger import ScriptTrigger
from .BaseEvent import BaseEvent
from .EventContainer import EventContainer
from .BaseLibrary import BaseLibrary

T = TypeVar("T")
java_util_function_Consumer_java_lang_Throwable_ = TypeVar("java_util_function_Consumer_java_lang_Throwable_")
Consumer = java_util_function_Consumer_java_lang_Throwable_

U = TypeVar("U")
java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

java_io_File = TypeVar("java_io_File")
File = java_io_File


class BaseLanguage(Generic[U, T]):
	"""Language class for languages to be implemented on top of.\n
	Since: 1.1.3 
	"""
	extension: Extension
	preThread: Runnable

	@overload
	def __init__(self, extension: Extension, runner: Core) -> None:
		pass

	@overload
	def trigger(self, macro: ScriptTrigger, event: BaseEvent, then: Runnable, catcher: Consumer) -> EventContainer:
		pass

	@overload
	def trigger(self, lang: str, script: str, fakeFile: File, event: BaseEvent, then: Runnable, catcher: Consumer) -> EventContainer:
		pass

	@overload
	def retrieveLibs(self, context: T) -> Mapping[str, BaseLibrary]:
		pass

	@overload
	def retrieveOnceLibs(self) -> Mapping[str, BaseLibrary]:
		pass

	@overload
	def retrievePerExecLibs(self, context: T) -> Mapping[str, BaseLibrary]:
		pass

	@overload
	def createContext(self, event: BaseEvent, file: File) -> T:
		pass

	pass





from typing import overload
from typing import List


class ExtensionClassLoader(URLClassLoader):

	@overload
	def __init__(self, urls: List[URL]) -> None:
		pass

	@overload
	def addURL(self, url: URL) -> None:
		pass

	pass





from typing import overload
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .IScreen import IScreen
from .MethodWrapper import MethodWrapper
from .ButtonWidgetHelper import ButtonWidgetHelper


class ButtonWidgetHelper_ButtonBuilder(AbstractWidgetBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, screen: IScreen) -> None:
		pass

	@overload
	def height(self, height: int) -> "ButtonWidgetHelper_ButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			height: this argument is ignored and will always be set to 20 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def size(self, width: int, height: int) -> "ButtonWidgetHelper_ButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the button 
			height: this argument is ignored and will always be set to 20 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAction(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the action to run when the button is pressed. 
		"""
		pass

	@overload
	def action(self, action: MethodWrapper) -> "ButtonWidgetHelper_ButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			action: the action to run when the button is pressed 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def createWidget(self) -> ButtonWidgetHelper:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping

net_minecraft_advancement_AdvancementProgress = TypeVar("net_minecraft_advancement_AdvancementProgress")
AdvancementProgress = net_minecraft_advancement_AdvancementProgress

net_minecraft_advancement_AdvancementEntry = TypeVar("net_minecraft_advancement_AdvancementEntry")
AdvancementEntry = net_minecraft_advancement_AdvancementEntry


class MixinClientAdvancementManager:
	"""
	Since: 1.8.4 
	"""

	@overload
	def getAdvancementProgresses(self) -> Mapping[AdvancementEntry, AdvancementProgress]:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .IllagerEntityHelper import IllagerEntityHelper

T = TypeVar("T")

class SpellcastingIllagerEntityHelper(Generic[T], IllagerEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def isCastingSpell(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this spell caster is currently casting a spell, 'false' otherwise. 
		"""
		pass

	@overload
	def getCastedSpell(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the spell this spell caster is currently casting. 
		"""
		pass

	pass





from typing import overload
from .RecipeInventory import RecipeInventory
from .ItemStackHelper import ItemStackHelper


class PlayerInventory(RecipeInventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def getInput(self, x: int, y: int) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the input from 0 to 1, going left to right 
			y: the y position of the input from 0 to 1, going top to bottom 

		Returns:
			the input item at the given position of the crafting grid. 
		"""
		pass

	@overload
	def isInHotbar(self, slot: int) -> bool:
		"""
		Since: 1.8.4 

		Args:
			slot: the slot to check 

		Returns:
			'true' if the slot is in the hotbar or the offhand slot, 'false' otherwise. 
		"""
		pass

	@overload
	def getOffhand(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the item in the offhand. 
		"""
		pass

	@overload
	def getHelmet(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped helmet item. 
		"""
		pass

	@overload
	def getChestplate(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped chestplate item. 
		"""
		pass

	@overload
	def getLeggings(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped leggings item. 
		"""
		pass

	@overload
	def getBoots(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the equipped boots item. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .AbstractMapSettingContainer import AbstractMapSettingContainer
from .SettingsOverlay import SettingsOverlay

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class ColorMapSetting(AbstractMapSettingContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: SettingsOverlay, group: List[str]) -> None:
		pass

	@overload
	def addField(self, key: str, value: List[float]) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .IScreen import IScreen
from .MethodWrapper import MethodWrapper
from .TextFieldWidgetHelper import TextFieldWidgetHelper

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class TextFieldWidgetHelper_TextFieldBuilder(AbstractWidgetBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, screen: IScreen, textRenderer: TextRenderer) -> None:
		pass

	@overload
	def getAction(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the callback for when the text is changed. 
		"""
		pass

	@overload
	def action(self, action: MethodWrapper) -> "TextFieldWidgetHelper_TextFieldBuilder":
		"""
		Since: 1.8.4 

		Args:
			action: the callback for when the text is changed 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getSuggestion(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current suggestion. 
		"""
		pass

	@overload
	def suggestion(self, suggestion: str) -> "TextFieldWidgetHelper_TextFieldBuilder":
		"""
		Since: 1.8.4 

		Args:
			suggestion: the suggestion to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def createWidget(self) -> TextFieldWidgetHelper:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_projectile_TridentEntity = TypeVar("net_minecraft_entity_projectile_TridentEntity")
TridentEntity = net_minecraft_entity_projectile_TridentEntity


class TridentEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: TridentEntity) -> None:
		pass

	@overload
	def hasLoyalty(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the trident is enchanted with loyalty, 'false' otherwise. 
		"""
		pass

	@overload
	def isEnchanted(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the trident is enchanted, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper
from .ItemStackHelper import ItemStackHelper

net_minecraft_entity_ItemEntity = TypeVar("net_minecraft_entity_ItemEntity")
ItemEntity = net_minecraft_entity_ItemEntity


class ItemEntityHelper(EntityHelper):

	@overload
	def __init__(self, e: ItemEntity) -> None:
		pass

	@overload
	def getContainedItemStack(self) -> ItemStackHelper:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .IPalettedContainerData import IPalettedContainerData

net_minecraft_world_chunk_Palette_T_ = TypeVar("net_minecraft_world_chunk_Palette_T_")
Palette = net_minecraft_world_chunk_Palette_T_

T = TypeVar("T")
net_minecraft_util_collection_PaletteStorage = TypeVar("net_minecraft_util_collection_PaletteStorage")
PaletteStorage = net_minecraft_util_collection_PaletteStorage


class MixinPalettedContainerData(IPalettedContainerData, Generic[T]):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getStorage(self) -> PaletteStorage:
		pass

	@overload
	def jsmacros_getPalette(self) -> Palette:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .IAdvancedFilter import IAdvancedFilter
from .IFilter import IFilter

T = TypeVar("T")

class BasicFilter(IAdvancedFilter, Generic[T]):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def and_(self, filter: IFilter) -> IAdvancedFilter:
		pass

	@overload
	def or_(self, filter: IFilter) -> IAdvancedFilter:
		pass

	@overload
	def xor(self, filter: IFilter) -> IAdvancedFilter:
		pass

	@overload
	def not_(self) -> IAdvancedFilter:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .IFilter import IFilter

T = TypeVar("T")

class IAdvancedFilter(IFilter, Generic[T]):
	"""
	Since: 1.6.5 
	"""

	@overload
	def and_(self, filter: IFilter) -> "IAdvancedFilter":
		pass

	@overload
	def or_(self, filter: IFilter) -> "IAdvancedFilter":
		pass

	@overload
	def xor(self, filter: IFilter) -> "IAdvancedFilter":
		pass

	@overload
	def not_(self) -> "IAdvancedFilter":
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder

U = TypeVar("U")

class ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder(Generic[U]):

	@overload
	def __init__(self, parent: U, constPool: ConstPool) -> None:
		pass

	@overload
	def putString(self, value: str) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putBoolean(self, value: bool) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putByte(self, value: float) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putChar(self, value: str) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putShort(self, value: float) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putInt(self, value: int) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putLong(self, value: float) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putFloat(self, value: float) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putDouble(self, value: float) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putClass(self, value: Class) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putEnum(self, value: ) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def putAnnotation(self, annotationClass: Class) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putArray(self, annotationClass: Class) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def finish(self) -> U:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_mob_BlazeEntity = TypeVar("net_minecraft_entity_mob_BlazeEntity")
BlazeEntity = net_minecraft_entity_mob_BlazeEntity


class BlazeEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: BlazeEntity) -> None:
		pass

	@overload
	def isOnFire(self) -> bool:
		"""A blaze can only shoot fireballs when it's on fire.\n
		Since: 1.8.4 

		Returns:
			'true' if the blaze is on fire, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_function_Consumer_xyz_wagyourtail_wagyourgui_elements_Slider_ = TypeVar("java_util_function_Consumer_xyz_wagyourtail_wagyourgui_elements_Slider_")
Consumer = java_util_function_Consumer_xyz_wagyourtail_wagyourgui_elements_Slider_

net_minecraft_client_gui_widget_ClickableWidget = TypeVar("net_minecraft_client_gui_widget_ClickableWidget")
ClickableWidget = net_minecraft_client_gui_widget_ClickableWidget

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class Slider(ClickableWidget):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, text: Text, value: float, action: Consumer, steps: int) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, text: Text, value: float, action: Consumer) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def roundValue(self, value: float) -> float:
		pass

	@overload
	def getValue(self) -> float:
		pass

	@overload
	def setValue(self, mouseX: float) -> None:
		pass

	@overload
	def getSteps(self) -> int:
		pass

	@overload
	def setSteps(self, steps: int) -> None:
		pass

	@overload
	def onClick(self, mouseX: float, mouseY: float) -> None:
		pass

	@overload
	def onRelease(self, mouseX: float, mouseY: float) -> None:
		pass

	@overload
	def setMessage(self, message: str) -> None:
		pass

	@overload
	def setMessage(self, message: Text) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_function_Consumer_java_lang_Double_ = TypeVar("java_util_function_Consumer_java_lang_Double_")
Consumer = java_util_function_Consumer_java_lang_Double_

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_gui_widget_ClickableWidget = TypeVar("net_minecraft_client_gui_widget_ClickableWidget")
ClickableWidget = net_minecraft_client_gui_widget_ClickableWidget


class Scrollbar(ClickableWidget):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, color: int, borderColor: int, highlightColor: int, scrollPages: float, onChange: Consumer) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> "Scrollbar":
		pass

	@overload
	def setScrollPages(self, scrollPages: float) -> None:
		pass

	@overload
	def scrollToPercent(self, percent: float) -> None:
		pass

	@overload
	def onClick(self, mouseX: float, mouseY: float) -> None:
		pass

	@overload
	def onChange(self) -> None:
		pass

	@overload
	def mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> bool:
		pass

	@overload
	def renderWidget(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent

T = TypeVar("T")
net_minecraft_client_gui_Element = TypeVar("net_minecraft_client_gui_Element")
Element = net_minecraft_client_gui_Element


class IContainerParent:

	@overload
	def addDrawableChild(self, drawableElement: T) -> T:
		pass

	@overload
	def remove(self, button: Element) -> None:
		pass

	@overload
	def openOverlay(self, overlay: OverlayContainer) -> None:
		pass

	@overload
	def openOverlay(self, overlay: OverlayContainer, disableButtons: bool) -> None:
		pass

	@overload
	def getFirstOverlayParent(self) -> IOverlayParent:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation

java_io_File = TypeVar("java_io_File")
File = java_io_File


class BaseWrappedException_GuestLocation(BaseWrappedException_SourceLocation):
	file: File
	line: int
	column: int
	startIndex: int
	endIndex: int

	@overload
	def __init__(self, file: File, startIndex: int, endIndex: int, line: int, column: int) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .Option import Option

java_lang_reflect_Field = TypeVar("java_lang_reflect_Field")
Field = java_lang_reflect_Field

T = TypeVar("T")
java_lang_reflect_Method = TypeVar("java_lang_reflect_Method")
Method = java_lang_reflect_Method


class SettingsOverlay_SettingField(Generic[T]):
	type: Class
	option: Option

	@overload
	def __init__(self, option: Option, containingClass: object, f: Field, getter: Method, setter: Method, type: Class) -> None:
		pass

	@overload
	def set(self, o: T) -> None:
		pass

	@overload
	def get(self) -> T:
		pass

	@overload
	def hasOptions(self) -> bool:
		pass

	@overload
	def getOptions(self) -> List[T]:
		pass

	@overload
	def isSimple(self) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar

B = TypeVar("B")
B = B


class Alignable:
	"""
	Since: 1.8.4 
	"""

	@overload
	def alignHorizontally(self, other: "Alignable", alignment: str) -> B:
		"""
		Since: 1.8.4 

		Args:
			other: the element to align to 
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alignHorizontally(self, other: "Alignable", alignment: str, offset: int) -> B:
		"""The alignment must be of the format '[left|center|right|x%]On[left|center|right|x%]' . The input is case-insensitive.
The first alignment is for the element this method is called on and the second is for the
other element. As an example, 'LeftOnCenter' would align the left side of this
element to the center of the other element.\n
		Since: 1.8.4 

		Args:
			other: the element to align to 
			offset: the offset to use 
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alignHorizontally(self, alignment: str) -> B:
		"""
		Since: 1.8.4 

		Args:
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alignHorizontally(self, alignment: str, offset: int) -> B:
		"""Possible alignments are 'left' , 'center' , 'right' or 'y%' where y
is a number between 0 and 100.\n
		Since: 1.8.4 

		Args:
			offset: the offset to use 
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alignVertically(self, other: "Alignable", alignment: str) -> B:
		"""
		Since: 1.8.4 

		Args:
			other: the element to align to 
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alignVertically(self, other: "Alignable", alignment: str, offset: int) -> B:
		"""The alignment must be of the format '[top|center|bottom|y%]On[top|center|bottom|y%]' . The input is case-insensitive.
The first alignment is for the element this method is called on and the second is for the
other element. As an example, 'BottomOnTop' would align the bottom side of this
element to the top of the other element. Thus, the element would be placed above the
other one.\n
		Since: 1.8.4 

		Args:
			other: the element to align to 
			offset: the offset to use 
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alignVertically(self, alignment: str) -> B:
		"""
		Since: 1.8.4 

		Args:
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def alignVertically(self, alignment: str, offset: int) -> B:
		"""Possible alignments are 'top' , 'center' , 'bottom' or 'x%' where x
is a number between 0 and 100.\n
		Since: 1.8.4 

		Args:
			offset: the offset to use 
			alignment: the alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def align(self, horizontal: str, vertical: str) -> B:
		"""
		Since: 1.8.4 

		Args:
			horizontal: the horizontal alignment to use 
			vertical: the vertical alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def align(self, horizontal: str, horizontalOffset: int, vertical: str, verticalOffset: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			horizontal: the horizontal alignment to use 
			verticalOffset: the vertical offset to use 
			vertical: the vertical alignment to use 
			horizontalOffset: the horizontal offset to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def align(self, other: "Alignable", horizontal: str, vertical: str) -> B:
		"""
		Since: 1.8.4 

		Args:
			horizontal: the horizontal alignment to use 
			other: the element to align to 
			vertical: the vertical alignment to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def align(self, other: "Alignable", horizontal: str, horizontalOffset: int, vertical: str, verticalOffset: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			horizontal: the horizontal alignment to use 
			other: the element to align to 
			verticalOffset: the vertical offset to use 
			vertical: the vertical alignment to use 
			horizontalOffset: the horizontal offset to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def moveTo(self, x: int, y: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			x: the new x position 
			y: the new y position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def moveToX(self, x: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			x: the new x position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def moveToY(self, y: int) -> B:
		"""
		Since: 1.8.4 

		Args:
			y: the new y position 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getScaledWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the scaled width of the element. 
		"""
		pass

	@overload
	def getParentWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the parent element. 
		"""
		pass

	@overload
	def getScaledHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the scaled height of the element. 
		"""
		pass

	@overload
	def getParentHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the parent element. 
		"""
		pass

	@overload
	def getScaledLeft(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the position of the scaled element's left side. 
		"""
		pass

	@overload
	def getScaledTop(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the position of the scaled element's top side. 
		"""
		pass

	@overload
	def getScaledRight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the position of the scaled element's right side. 
		"""
		pass

	@overload
	def getScaledBottom(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the position of the scaled element's bottom side. 
		"""
		pass

	@overload
	def parsePercentage(self, string: str) -> int:
		"""Parse the string containing a percentage of the form 'x%' and return its value.\n
		Since: 1.8.4 

		Args:
			string: the string to parse 

		Returns:
			the percentage or '-1' if the string is not a valid percentage. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .IContainerParent import IContainerParent
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent

T = TypeVar("T")
net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_gui_Element = TypeVar("net_minecraft_client_gui_Element")
Element = net_minecraft_client_gui_Element

net_minecraft_client_gui_widget_ClickableWidget = TypeVar("net_minecraft_client_gui_widget_ClickableWidget")
ClickableWidget = net_minecraft_client_gui_widget_ClickableWidget

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class MultiElementContainer(IContainerParent, Generic[T]):
	parent: T
	x: int
	y: int
	width: int
	height: int

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: T) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def getVisible(self) -> bool:
		pass

	@overload
	def setVisible(self, visible: bool) -> None:
		pass

	@overload
	def addDrawableChild(self, drawableElement: T) -> T:
		pass

	@overload
	def getButtons(self) -> List[ClickableWidget]:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> None:
		pass

	@overload
	def openOverlay(self, overlay: OverlayContainer) -> None:
		pass

	@overload
	def openOverlay(self, overlay: OverlayContainer, disableButtons: bool) -> None:
		pass

	@overload
	def remove(self, button: Element) -> None:
		pass

	@overload
	def getFirstOverlayParent(self) -> IOverlayParent:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from .FormattingHelper import FormattingHelper
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .EntityHelper import EntityHelper
from .MethodWrapper import MethodWrapper
from .StyleHelper import StyleHelper


class TextBuilder:
	"""usage: 'builder.append("hello,").withColor(0xc).append(" World!").withColor(0x6)'\n
	Since: 1.3.0 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def append(self, text: object) -> "TextBuilder":
		"""move on to next section and set it's text.\n
		Since: 1.3.0 

		Args:
			text: a String , TextHelper or TextBuilder 
		"""
		pass

	@overload
	def withColor(self, color: int) -> "TextBuilder":
		"""set current section's color by color code as hex, like '0x6' for gold
and '0xc' for red.\n
		Since: 1.3.0 

		Args:
			color: 
		"""
		pass

	@overload
	def withColor(self, r: int, g: int, b: int) -> "TextBuilder":
		"""Add text with custom colors.\n
		Since: 1.3.1 

		Args:
			r: red '0-255' 
			b: blue '0-255' 
			g: green '0-255' 
		"""
		pass

	@overload
	def withFormatting(self, underline: bool, bold: bool, italic: bool, strikethrough: bool, magic: bool) -> "TextBuilder":
		"""set other formatting options for the current section\n
		Since: 1.3.0 

		Args:
			magic: 
			underline: 
			bold: 
			strikethrough: 
			italic: 
		"""
		pass

	@overload
	def withFormatting(self, formattings: List[FormattingHelper]) -> "TextBuilder":
		"""
		Since: 1.8.4 

		Args:
			formattings: the formattings to apply 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def withShowTextHover(self, text: TextHelper) -> "TextBuilder":
		"""set current section's hover event to show text\n
		Since: 1.3.0 

		Args:
			text: 
		"""
		pass

	@overload
	def withShowItemHover(self, item: ItemStackHelper) -> "TextBuilder":
		"""set current section's hover event to show an item\n
		Since: 1.3.0 

		Args:
			item: 
		"""
		pass

	@overload
	def withShowEntityHover(self, entity: EntityHelper) -> "TextBuilder":
		"""set current section's hover event to show an entity\n
		Since: 1.3.0 

		Args:
			entity: 
		"""
		pass

	@overload
	def withCustomClickEvent(self, action: MethodWrapper) -> "TextBuilder":
		"""custom click event.\n
		Since: 1.3.0 

		Args:
			action: 
		"""
		pass

	@overload
	def withClickEvent(self, action: str, value: str) -> "TextBuilder":
		"""normal click events like: 'open_url' , 'open_file' , 'run_command' , 'suggest_command' , 'change_page' , and 'copy_to_clipboard'\n
		Since: 1.3.0 

		Args:
			action: 
			value: 
		"""
		pass

	@overload
	def withStyle(self, style: StyleHelper) -> "TextBuilder":
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of this text. 
		"""
		pass

	@overload
	def build(self) -> TextHelper:
		"""Build to a TextHelper\n
		Since: 1.3.0 
		"""
		pass

	pass





from typing import overload
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .IScreen import IScreen
from .MethodWrapper import MethodWrapper
from .LockButtonWidgetHelper import LockButtonWidgetHelper


class LockButtonWidgetHelper_LockButtonBuilder(AbstractWidgetBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, screen: IScreen) -> None:
		pass

	@overload
	def isLocked(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			the initial state of the lock button. 
		"""
		pass

	@overload
	def locked(self, locked: bool) -> "LockButtonWidgetHelper_LockButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			locked: whether to initially lock the button or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAction(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the action to run when the button is pressed. 
		"""
		pass

	@overload
	def action(self, action: MethodWrapper) -> "LockButtonWidgetHelper_LockButtonBuilder":
		"""
		Since: 1.8.4 

		Args:
			action: the action to run when the button is pressed 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def createWidget(self) -> LockButtonWidgetHelper:
		pass

	pass





from typing import overload


class IChunkSection:

	@overload
	def jsmacros_getNonEmptyBlockCount(self) -> float:
		pass

	@overload
	def jsmacros_getRandomTickableBlockCount(self) -> float:
		pass

	@overload
	def jsmacros_getNonEmptyFluidCount(self) -> float:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Set
from typing import Generic
from .BaseEvent import BaseEvent
from .EventContainer import EventContainer
from .BaseScriptContext_SleepRunnable import BaseScriptContext_SleepRunnable

T = TypeVar("T")
java_lang_ref_WeakReference_java_lang_Object_ = TypeVar("java_lang_ref_WeakReference_java_lang_Object_")
WeakReference = java_lang_ref_WeakReference_java_lang_Object_

java_io_File = TypeVar("java_io_File")
File = java_io_File

java_util_WeakHashMap_xyz_wagyourtail_jsmacros_core_event_IEventListener,java_lang_String_ = TypeVar("java_util_WeakHashMap_xyz_wagyourtail_jsmacros_core_event_IEventListener,java_lang_String_")
WeakHashMap = java_util_WeakHashMap_xyz_wagyourtail_jsmacros_core_event_IEventListener,java_lang_String_

java_lang_Thread = TypeVar("java_lang_Thread")
Thread = java_lang_Thread


class BaseScriptContext(Generic[T]):
	"""
	Since: 1.4.0 
	"""
	startTime: float
	syncObject: WeakReference
	triggeringEvent: BaseEvent
	eventListeners: WeakHashMap
	hasMethodWrapperBeenInvoked: bool

	@overload
	def __init__(self, event: BaseEvent, file: File) -> None:
		pass

	@overload
	def getSyncObject(self) -> object:
		"""this object should only be weak referenced unless we want to prevent the context from closing when syncObject is cleared.
		"""
		pass

	@overload
	def clearSyncObject(self) -> None:
		pass

	@overload
	def shouldKeepAlive(self) -> bool:
		pass

	@overload
	def getBoundEvents(self) -> Mapping[Thread, EventContainer]:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def bindEvent(self, th: Thread, event: EventContainer) -> None:
		"""
		Since: 1.6.0 

		Args:
			th: 
			event: 
		"""
		pass

	@overload
	def releaseBoundEventIfPresent(self, thread: Thread) -> bool:
		"""
		Since: 1.6.0 

		Args:
			thread: 
		"""
		pass

	@overload
	def getContext(self) -> T:
		pass

	@overload
	def getMainThread(self) -> Thread:
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def bindThread(self, t: Thread) -> bool:
		"""
		Since: 1.6.0 

		Args:
			t: 

		Returns:
			is a newly bound thread 
		"""
		pass

	@overload
	def unbindThread(self, t: Thread) -> None:
		"""
		Since: 1.6.0 

		Args:
			t: 
		"""
		pass

	@overload
	def getBoundThreads(self) -> Set[Thread]:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def setMainThread(self, t: Thread) -> None:
		"""
		Since: 1.5.0 

		Args:
			t: 
		"""
		pass

	@overload
	def getTriggeringEvent(self) -> BaseEvent:
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def setContext(self, context: T) -> None:
		pass

	@overload
	def isContextClosed(self) -> bool:
		pass

	@overload
	def closeContext(self) -> None:
		pass

	@overload
	def getFile(self) -> File:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def getContainedFolder(self) -> File:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def isMultiThreaded(self) -> bool:
		pass

	@overload
	def wrapSleep(self, sleep: BaseScriptContext_SleepRunnable) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent

com_mojang_brigadier_context_CommandContext__ = TypeVar("com_mojang_brigadier_context_CommandContext__")
CommandContext = com_mojang_brigadier_context_CommandContext__

com_mojang_brigadier_context_StringRange = TypeVar("com_mojang_brigadier_context_StringRange")
StringRange = com_mojang_brigadier_context_StringRange


class CommandContextHelper(BaseEvent):
	"""
	Since: 1.4.2 
	"""

	@overload
	def __init__(self, base: CommandContext) -> None:
		pass

	@overload
	def getRaw(self) -> CommandContext:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def equals(self, obj: object) -> bool:
		pass

	@overload
	def getArg(self, name: str) -> object:
		"""
		Since: 1.4.2 

		Args:
			name: 
		"""
		pass

	@overload
	def getChild(self) -> "CommandContextHelper":
		pass

	@overload
	def getRange(self) -> StringRange:
		pass

	@overload
	def getInput(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping

net_minecraft_text_MutableText = TypeVar("net_minecraft_text_MutableText")
MutableText = net_minecraft_text_MutableText

io_noties_prism4j_AbsVisitor = TypeVar("io_noties_prism4j_AbsVisitor")
AbsVisitor = io_noties_prism4j_AbsVisitor

net_minecraft_text_Style = TypeVar("net_minecraft_text_Style")
Style = net_minecraft_text_Style


class TextStyleCompiler(AbsVisitor):

	@overload
	def __init__(self, defaultStyle: Style, themeData: Mapping[str, List[float]]) -> None:
		pass

	@overload
	def getResult(self) -> List[MutableText]:
		pass

	pass





from typing import overload
from typing import List
from .ClassBuilder_MethodBuilder import ClassBuilder_MethodBuilder
from .ClassBuilder import ClassBuilder
from .MethodWrapper import MethodWrapper
from .ClassBuilder_BodyBuilder import ClassBuilder_BodyBuilder


class ClassBuilder_ConstructorBuilder("ClassBuilder_MethodBuilder"):

	@overload
	def __init__(self, params: List[CtClass], clInit: bool) -> None:
		pass

	@overload
	def body(self, code_src: str) -> "ClassBuilder":
		pass

	@overload
	def guestBody(self, methodBody: MethodWrapper) -> "ClassBuilder":
		pass

	@overload
	def buildBody(self) -> "ClassBuilder_BodyBuilder":
		pass

	@overload
	def body(self, buildBody: MethodWrapper) -> "ClassBuilder":
		pass

	@overload
	def endAbstract(self) -> "ClassBuilder":
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .WrappedClassInstance import WrappedClassInstance

T = TypeVar("T")

class Mappings_MappedClass(Generic[T], WrappedClassInstance):
	"""
	Since: 1.6.0 
	"""

	@overload
	def __init__(self, instance: T) -> None:
		pass

	@overload
	def __init__(self, instance: T, type: Class) -> None:
		pass

	pass


